| build_lineups,optimizer-method | R Documentation |
Method to Generate lineups
## S4 method for signature 'optimizer' build_lineups( object, num_lineups = 1, existing_lineups = list(), solver = "glpk", maximize = TRUE, verbose = TRUE )
object |
an S4 object of class Optimizer |
num_lineups |
Number of lineups to generate |
existing_lineups |
Optional. You can include previously defined lineups by passing the lineupClass output of a previous |
solver |
The solver method (defaults to 'glpk'). |
maximize |
Whether the model is intended to maximize (the default) or minimize the objective function |
verbose |
Whether to show a progress bar when building models. Defaults to TRUE. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.