| get_players_from_csv,YahooOptim-method | R Documentation |
Create Players from CSV
Create Players from CSV
## S4 method for signature 'YahooOptim' get_players_from_csv(object, path) ## S4 method for signature 'FanduelOptim' get_players_from_csv(object, path)
object |
Optimizer object |
path |
Path to CSV or text file |
Reads a CSV from a specified site, and generates objects of Player class (one per row)
Reads a CSV from a specified site, and generates objects of Player class (one per row)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.